==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/relay/kotlin/outputs/GetHybridConnectionResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.relay.kotlin.outputs

import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress

/**
 * Description of hybrid connection resource.
 * @property createdAt The time the hybrid connection was created.
 * @property id Fully qualified resource ID for the resource. Ex - /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}
 * @property listenerCount The number of listeners for this hybrid connection. Note that min : 1 and max:25 are supported.
 * @property location The geo-location where the resource lives
 * @property name The name of the resource
 * @property requiresClientAuthorization Returns true if client authorization is needed for this hybrid connection; otherwise, false.
 * @property systemData The system meta data relating to this resource.
 * @property type The type of the resource. E.g. "Microsoft.EventHub/Namespaces" or "Microsoft.EventHub/Namespaces/EventHubs"
 * @property updatedAt The time the namespace was updated.
 * @property userMetadata The usermetadata is a placeholder to store user-defined string data for the hybrid connection endpoint. For example, it can be used to store descriptive data, such as a list of teams and their contact information. Also, user-defined configuration settings can be stored.
 */
public data class GetHybridConnectionResult(
    public val createdAt: String,
    public val id: String,
    public val listenerCount: Int,
    public val location: String,
    public val name: String,
    public val requiresClientAuthorization: Boolean? = null,
    public val systemData: SystemDataResponse,
    public val type: String,
    public val updatedAt: String,
    public val userMetadata: String? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.relay.outputs.GetHybridConnectionResult):
            GetHybridConnectionResult = GetHybridConnectionResult(
            createdAt = javaType.createdAt(),
            id = javaType.id(),
            listenerCount = javaType.listenerCount(),
            location = javaType.location(),
            name = javaType.name(),
            requiresClientAuthorization = javaType.requiresClientAuthorization().map({ args0 ->
                args0
            }).orElse(null),
            systemData = javaType.systemData().let({ args0 ->
                com.pulumi.azurenative.relay.kotlin.outputs.SystemDataResponse.Companion.toKotlin(args0)
            }),
            type = javaType.type(),
            updatedAt = javaType.updatedAt(),
            userMetadata = javaType.userMetadata().map({ args0 -> args0 }).orElse(null),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/relay/kotlin/outputs/GetHybridConnectionResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.relay.kotlin.outputs

import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress

/**
 * Description of hybrid connection resource.
 * @property createdAt The time the hybrid connection was created.
 * @property id Fully qualified resource ID for the resource. Ex - /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}
 * @property listenerCount The number of listeners for this hybrid connection. Note that min : 1 and max:25 are supported.
 * @property location The geo-location where the resource lives
 * @property name The name of the resource
 * @property requiresClientAuthorization Returns true if client authorization is needed for this hybrid connection; otherwise, false.
 * @property systemData The system meta data relating to this resource.
 * @property type The type of the resource. E.g. "Microsoft.EventHub/Namespaces" or "Microsoft.EventHub/Namespaces/EventHubs"
 * @property updatedAt The time the namespace was updated.
 * @property userMetadata The usermetadata is a placeholder to store user-defined string data for the hybrid connection endpoint. For example, it can be used to store descriptive data, such as a list of teams and their contact information. Also, user-defined configuration settings can be stored.
 */
public data class GetHybridConnectionResult(
    public val createdAt: String,
    public val id: String,
    public val listenerCount: Int,
    public val location: String,
    public val name: String,
    public val requiresClientAuthorization: Boolean? = null,
    public val systemData: SystemDataResponse,
    public val type: String,
    public val updatedAt: String,
    public val userMetadata: String? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.relay.outputs.GetHybridConnectionResult): GetHybridConnectionResult = GetHybridConnectionResult(
            createdAt = javaType.createdAt(),
            id = javaType.id(),
            listenerCount = javaType.listenerCount(),
            location = javaType.location(),
            name = javaType.name(),
            requiresClientAuthorization = javaType.requiresClientAuthorization().map({ args0 ->
                args0
            }).orElse(null),
            systemData = javaType.systemData().let({ args0 ->
                com.pulumi.azurenative.relay.kotlin.outputs.SystemDataResponse.Companion.toKotlin(args0)
            }),
            type = javaType.type(),
            updatedAt = javaType.updatedAt(),
            userMetadata = javaType.userMetadata().map({ args0 -> args0 }).orElse(null),
        )
    }
}
